@@ -492,7 +492,7 @@ def FieldDetermination(Fields,plot=False,**kwargs):
         baixo = values[:,lista1.index(bodyPartBox+" - y")].min()
         cima = values[:,lista1.index(bodyPartBox+" - y")].max()
 
-    if type(posit) == None:
+    if type(posit) == type(None):
         for i in range(Fields):
             print('Enter the object type '+ str(i+1) + " (0 - circular, 1 - rectangular):")
             objectType = int(input())
